/*
 * Licensed Materials - Property of IBM
 * 5725-G92 (C) Copyright IBM Corp. 2012, 2013. All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
(function($) {
	var daysOfWeekShort = ['Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa'];
	var monthsOfYearShort = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];
	
//	window.ft.timeOffset = 0;
	window.ft.cityMap = {"London":"LHR","HongKong":"HKG","Amsterdam":"AMS","Mumbai":"BOM"};
	window.ft.departAP = 'London';
	window.ft.destAP = 'HongKong';
	window.ft.departureDate = new Date().format('yyyy-MM-dd');
	window.ft.returnDate = new Date().format('yyyy-MM-dd');
	window.ft.cabinClass = 'ECONOMY';
//	window.ft.isSearchingReturnFlight = false;
	
	window.searchFlights = function(success, queryParams) {
		var invocationData = {
			adapter : "FTAdapter",
			procedure : "FlightsREST_getTripFlights",
			parameters : [queryParams || window.ft.flightQueryParams]
		};
		WL.Client.invokeProcedure(invocationData, {
			onSuccess: function(resp) {
				var rawResult = resp.invocationResult;
				var result = {flightList: []};
				
				$.each(rawResult.tripFlights[0].flightsOptions, function(i, flight) {
					result.flightList.push({
						departAP: "",
						destAP: "",
						departDate: "",
						departTime: flight.scheduledDepartureTime,
						reachTime: flight.scheduledArrivalTime,
						price: flight.economyClassBaseCost, 
						flightSegmentId: flight.flightSegmentId, 
						airplaneTypeId: flight.airplaneTypeId, 
						seats: flight.numEconomyClassSeats,
						flightId: flight.pkey.id
					});
				});
				
				resp = {invocationResult:result};
				if($.isFunction(success)) {
					success(resp);
				}
			},
			onFailure: function(resp) {
				console.log("invoke FTAdapter failed: " + resp);
			}
		});
	};
	
	window.parseResult = function(result, isRoundTrip){
		$.each(result, function(i, item) {
			if(isRoundTrip) {
				item.departAP = window.ft.destAP;
				item.destAP = window.ft.departAP;
				item.departDate = new Date(window.ft.returnDate).setHours(0,0,0,0);
			} else {
				item.departAP = window.ft.departAP;
				item.destAP = window.ft.destAP;
				item.departDate = new Date(window.ft.departureDate).setHours(0,0,0,0);
			}
		});
		return result;
	};
	
	function setDate(date, isDeparture) {
//		var isDeparture = (id == 'departureDate'); 
		var prefix = isDeparture ? 'depart' : 'return';
		date = new Date(Date.parse(date.replace(/-/g, '/')));
		
		if(isDeparture) {
			window.ft.departureDate = date.format('yyyy-MM-dd');
		} else {
			window.ft.returnDate = date.format('yyyy-MM-dd');
		}
		
		$('#' + prefix + 'Day').text(date.getDate());
		$('#' + prefix + 'Month').text(monthsOfYearShort[date.getMonth()]);
		$('#' + prefix + 'Week').text(daysOfWeekShort[date.getDay()]);
	};
	
	function selectTripType(isRoundTrip) {
		if(isRoundTrip) {
			$('#roundTripLabel').addClass('ui-radio-on ui-btn-active');
			$('#roundTrip').attr('checked', true);
			$('#returnLabel').css('display', 'inline-block');
			$('#singleTripLabel').removeClass('ui-radio-on ui-btn-active');
		} else {
			$('#singleTripLabel').addClass('ui-radio-on ui-btn-active');
			$('#singleTrip').attr('checked', true);
			$('#returnLabel').css('display', 'none');
			$('#roundTripLabel').removeClass('ui-radio-on ui-btn-active');
		}
	}
	
	$("#flightPage").live("pageinit", function() {
//		ft.util.decorateButtons("#flightPage .backBtn");
		linkBD('#departLink, #destLink', 'airportSelect.html', {
			isListItem: true,
			onBeforeChange: function() {
				window.ft.isSetDepartAP = ($(this).attr('id') == 'departLink'); 
			}
		});
		linkBD('#cabinClassOptsLink', '#cabinClassOpts', { 
			isPopup: true, isListItem: true 
		});
		
		/*
		$('#departureDate, #returnDate').bind('datebox', function(e, p) {
			if(p.method == 'close') {
				var val = $(this).val();
				if(val) {
					setDate(val, ($(this).attr('id') == 'departureDate'));
				}
			}
		});
		*/
		
		$('#departureDate, #returnDate').on('change', function() {
			var val = $(this).val();
			if(val) {
				setDate(val, ($(this).attr('id') == 'departureDate'));
			}
		}).mobiscroll().date({
			theme: 'ios',
			display: 'bottom',
			mode: 'scroller',
			dateOrder: 'mmD ddyy',
			onClose: function(val, inst) {
				if(window.ft.isSetDate) {
					var date = val.split('/');
					date[0] = '' + (parseInt(date[0], 10) - 1);
					$(window.ft.isSetDepartDate ? '#departureDate' : '#returnDate')
						.mobiscroll('setValue', date, true);
				}
			}
	    });
		
		$('#singleTrip, #roundTrip').bind('click', function() {
            if($('#singleTrip').attr('checked') == 'checked') {
            	$('#returnLabel').css('display', 'none');
            	window.ft.isRoundTrip = false;
            } else {
            	$('#returnLabel').css('display', 'inline-block');
            	window.ft.isRoundTrip = true;
            }
            selectTripType(window.ft.isRoundTrip);
		});
		
		$('#departureLabel').on('tap', function(e) {
			e.stopImmediatePropagation();
			e.preventDefault();
			window.ft.isSetDepartDate = true;
			$('#departureDate').mobiscroll('show');
//			$('#departureDate').datebox('open');
		});
		$('#returnLabel').on('tap', function(e) {
			e.stopImmediatePropagation();
			e.preventDefault();
			window.ft.isSetDepartDate = false;
			$('#returnDate').mobiscroll('show');
//			$('#returnDate').datebox('open');
		});
		
		$('input[name=cabinClass]').on('click', function(e) {
			$('#cabinClassOptsLi').removeClass('ui-btn-active');
			window.ft.cabinClass = $(this).val();
			$('#cabinClass').text($(this).next('label').text());
			$("#cabinClassOpts").popup("close");
		});
		
//		$(document).on('tap', '.dw-bottom .dwb', function(e) {
//			e.stopImmediatePropagation();
//			e.preventDefault();
//			if($(this).parent().hasClass('dwb-s')) {
//				window.ft.isSetDate = true; // set date
//			} else {
//				window.ft.isSetDate = false; // cancel
//			}
//			$(window.ft.isSetDepartDate ? '#departureDate' : '#returnDate').mobiscroll('hide');
//		}).on('vmousedown', function() {
//			$(this).addClass('dwb-a');
//		}).on('vmouseup', function() {
//			$(this).removeClass('dwb-a');
//		});
		
		$.mobile.loadPage("flightSearchResult.html");
		addActiveEffect('#searchFlights');
		$('#searchFlights').bind('tap', function() {
			busy.show();
			window.ft.flightQueryParams = {
				fromAirport: window.ft.cityMap[window.ft.departAP],
				toAirport: window.ft.cityMap[window.ft.destAP],
				fromDate: new Date(window.ft.departureDate).setHours(0,0,0,0),
				returnDate: new Date(window.ft.returnDate).setHours(0,0,0,0),
				oneWay: true
			};
			wait(1, function() {
				searchFlights(function(resp) {
					console.log(resp);
					window.ft.outboundFlightList = parseResult(resp.invocationResult.flightList);
					$.mobile.changePage("selectOutboundFlight.html");
				});
				busy.hide();
			});
			return false;
		});
	});
	
	$("#flightPage").live("pagebeforeshow", function() {
		$('#departAP').text(window.ft.departAP);
		$('#destAP').text(window.ft.destAP);
		
		setDate(window.ft.departureDate, true);
		setDate(window.ft.returnDate, false);
		selectTripType(window.ft.isRoundTrip);
	});
})(jq);