/*
 * Licensed Materials - Property of IBM
 * 5725-G92 (C) Copyright IBM Corp. 2012, 2013. All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
(function($) {
	function renderFlightList() {
		$('#outboundFlightList').html($('#outboundFlightList .template'));
		if(!window.ft.outboundFlightList || window.ft.outboundFlightList.length == 0) {
			$('#outboundFlightList .template.noOutboundFlights').show();
		} else {
			$('#outboundFlightList .template.noOutboundFlights').hide();
			var props = ['departTime', 'reachTime', 'price', 'seats', 'flightSegmentId', 'airplaneTypeId'];
			$.each(window.ft.outboundFlightList, function(i, flight) {
				var $itemFlight = $('#outboundFlightList .template.outboundFlight').clone();
				$.each(props, function(i, prop) {
					var value = flight[prop];
					if(prop == 'price') {
						value = '$' + value;
					}
					if(-1 != prop.indexOf('Time') && typeof(value) !== 'string'){
						value = (new Date(value)).format('hh:mm');
						flight[prop] = value;
					}
					$('.' + prop, $itemFlight).html(value);
				});
				$itemFlight.removeClass('template')
					.attr('data-flight-index', i).appendTo('#outboundFlightList').show();
			});
		}
		$('#outboundFlightList').listview('refresh');
	}
	
	function displayDate(date) {
		$.each({
			'dayOfWeek': DAYS_OF_WEEK_SHORT[date.getDay()],
			'day': date.getDate(),
			'month': MONTHS_OF_YEAR[date.getMonth()],
			'year': date.getFullYear()
		}, function(prop, value) {
			$('.flight-date .departDate .' + prop, $('#selectOutboundFlightPage')).text(value);
		});
	}
	
	$("#selectOutboundFlightPage").live("pagebeforeshow", function() {
		var departDate = new Date(Date.parse(window.ft.departureDate.replace(/-/g, '/')));
		displayDate(departDate);
		
		$('.depart-airport .departAP', $(this)).text(window.ft.departAP);
		$('.dest-airport .destAP', $(this)).text(window.ft.destAP);
		
		renderFlightList();
	});
	
	$("#selectOutboundFlightPage").live("pageinit", function() {
//		ft.util.decorateButtons("#selectOutboundFlightPage .backBtn");
		
		$('#outboundFlightList').on('tap', '.outboundFlight', function(e) {
			e.stopImmediatePropagation();
			e.preventDefault();
			var idx = $(this).attr('data-flight-index');
			window.ft.outboundFlight = window.ft.outboundFlightList[idx];
			
			if(window.ft.isRoundTrip) {
				var queryParams = $.extend({}, window.ft.flightQueryParams, {
					fromAirport: window.ft.cityMap[window.ft.destAP],
					toAirport: window.ft.cityMap[window.ft.departAP],
					fromDate: new Date(window.ft.returnDate).setHours(0,0,0,0)
				});
				
				searchFlights(function(resp) {
					window.ft.returnFlightList = parseResult(resp.invocationResult.flightList, true);
					$.mobile.changePage('selectReturnFlight.html');
				}, queryParams);
			} else {
				$.mobile.changePage('bookTicket.html');
			}
		}).on('vmousedown', '.outboundFlight', function(e) {
			$target = $(this).closest('li');
			$(this).addClass('ui-btn-active');
			window.ft.$activeLinks.push($target);
		}).on('vmousemove', '.outboundFlight', function(e) {
			$(this).closest('li').removeClass('ui-btn-active');
		});
		
		$('.prev-btn, .next-btn', $(this)).on('tap', function(e) {
			var isNext = $(this).hasClass('next-btn');
			busy.show();
			wait(1, function() {
				var date = new Date(window.ft.departureDate.replace(/-/g, '/'));
                date.setDate(date.getDate() + (isNext ? 1 : -1));
                displayDate(date);
				window.ft.departureDate = date.format('yyyy-MM-dd');
				
				var queryParams = $.extend({}, window.ft.flightQueryParams, {
					fromDate: date.setHours(0,0,0,0)
				});
				searchFlights(function(resp) {
					console.log(resp);
					window.ft.outboundFlightList = parseResult(resp.invocationResult.flightList);
					renderFlightList();
					busy.hide();
				}, queryParams);
			});
			return false;
		});
	});
})(jq);